import pulumi
import pulumi_aws 

from typing import List, Mapping, Optional, Literal
from theia.aws.containers.common.utils import ClusterVpcArgs
from theia.definitions import AWS_REGION, THEIA_VERSION
from theia import ResourceOptions

class ECSClusterVpcArgs(ClusterVpcArgs):
    pass

class ECSCluster:
    def __new__(cls,
        resource_name: str,
        subnet_ids: List[str],
        cluster_vpc_args: Optional[ECSClusterVpcArgs] = ECSClusterVpcArgs(),
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
        ) -> pulumi_aws.ecs.Cluster:

        merged_tags = THEIA_VERSION
        name = {"Name": resource_name}
        if tags:
            merged_tags = {**tags, **name, **merged_tags}
        
        cluster = pulumi_aws.ecs.Cluster(
            resource_name=resource_name,
            name=resource_name,
            tags=merged_tags,
            opts=opts
        )

        # Export the load balancer DNS name
        pulumi.export(
            f"ECS-cluster---{resource_name}",
            { 
                    "arn": cluster.arn,
                    "id": cluster.id,
                    "service-connect-defaults": cluster.service_connect_defaults
            }
        )

        return cluster
