import pulumi

from pulumi_aws import cloudwatch

from typing import Optional, Mapping

from theia import ResourceOptions
from theia.definitions import THEIA_VERSION
from theia._registry import StackRegistry, GlobalTags


class LogGroup:
    def __new__(
        cls,
        resource_name: str,
        kms_key_id: Optional[str] = None,
        retention_in_days: Optional[int] = 180,
        skip_destroy: Optional[bool] = False,
        tags: Optional[Mapping[str, str]] = None,
        opts: Optional[ResourceOptions] = None,
    ) -> cloudwatch.LogGroup:
        name = {"Name": resource_name}
        merged_tags = THEIA_VERSION | GlobalTags.get() | name
        if tags:
            merged_tags = tags | merged_tags

        log_group = cloudwatch.LogGroup(
            resource_name,
            name=resource_name,
            kms_key_id=kms_key_id,
            retention_in_days=retention_in_days,
            skip_destroy=skip_destroy,
            opts=opts,
        )

        pulumi.export(
            f"cw-log-group---{resource_name}",
            {"arn": log_group.arn, "id": log_group.id},
        )

        return log_group

    @staticmethod
    def import_(stack: str, resource_name: str) -> cloudwatch.LogGroup:
        stack_ref = StackRegistry.get(stack_name=stack)
        lg = stack_ref.get_output(name=f"cw-log-group---{resource_name}")
        return cloudwatch.LogGroup.get(resource_name=resource_name, id=lg["id"])
